Phenotype Simulation Module
===========================

.. currentmodule:: plastro.phenotype_simulation

The phenotype simulation module provides functions for generating synthetic single-cell datasets with realistic branching differentiation trajectories and phenotypic transitions.

Core Functions
--------------

.. autosummary::
   :toctree: generated/

   generate_ad
   simulate_realistic_dataset
   create_random_binary_tree
   subset_to_terminal_branches

Utility Functions
-----------------

.. autosummary::
   :toctree: generated/

   sample_branch
   rgba_to_hex

Function Details
----------------

.. automodule:: plastro.phenotype_simulation
   :members:
   :undoc-members:
   :show-inheritance: